@@ -7,6 +7,91 @@ from syntropynac.exceptions import ConfigureNetworkError
 from syntropynac.fields import ConfigFields, PeerState
 
 
+def get_topology(network, config, silent):
+    topology = config[ConfigFields.TOPOLOGY].upper()
+    if topology != network[ConfigFields.TOPOLOGY] and not config.get(
+        ConfigFields.IGNORE_NETWORK_TOPOLOGY, False
+    ):
+        error = f"Configured and requested network topologies do not match: {network[ConfigFields.TOPOLOGY]} v.s. {topology}."
+        if not silent:
+            click.secho(
+                error,
+                err=True,
+                fg="red",
+            )
+            return False
+        else:
+            raise ConfigureNetworkError(error)
+    elif topology != network[ConfigFields.TOPOLOGY] and config.get(
+        ConfigFields.IGNORE_NETWORK_TOPOLOGY, False
+    ):
+        click.secho(
+            (
+                f"Configured and requested network topologies do not match: "
+                f"{network[ConfigFields.TOPOLOGY]} v.s. {topology}. However, "
+                f"{ConfigFields.IGNORE_NETWORK_TOPOLOGY} is set."
+            ),
+            err=True,
+            fg="yellow",
+        )
+        if network[ConfigFields.TOPOLOGY] != sdk.MetadataNetworkType.P2P:
+            click.secho(
+                "NOTE: It is more practical to override P2P topologies.",
+                err=True,
+                fg="yellow",
+            )
+    return topology
+
+
+def create_connections(api, network_id, network_name, peers, silent=False):
+    body = {
+        "network_ids": [network_id],
+        "agent_ids": [{"agent_1_id": a, "agent_2_id": b} for a, b in peers],
+        "network_update_by": sdk.NetworkGenesisType.CONFIG,
+    }
+
+    utils.BatchedRequestBody(
+        api.platform_connection_create_p2p,
+        translator=utils._default_translator("agent_ids"),
+        max_payload_size=utils.MAX_PAYLOAD_SIZE,
+    )(body=body)
+
+    connections = utils.WithRetry(api.platform_connection_index)(
+        filter=f"networks[]:{network_id}",
+        take=utils.TAKE_MAX_ITEMS_PER_CALL,
+    )["data"]
+
+    frozen_peers = [frozenset(peer) for peer in peers]
+    connections = [
+        con
+        for con in connections
+        if frozenset((con["agent_1"]["agent_id"], con["agent_2"]["agent_id"]))
+        in frozen_peers
+    ]
+
+    not silent and click.echo(
+        f"Created {len(connections)} connections for network {network_name}"
+    )
+
+    return connections
+
+
+def delete_connections(api, absent):
+    body = [
+        {
+            "agent_1_id": a,
+            "agent_2_id": b,
+        }
+        for a, b in absent
+    ]
+
+    utils.BatchedRequestBody(
+        api.platform_connection_destroy,
+        translator=lambda body, data: body[:] if data is None else data[:],
+        max_payload_size=utils.MAX_PAYLOAD_SIZE,
+    )(body=body)
+
+
 def configure_connection(api, config, connection, silent=False):
     agents = {
         connection["agent_1"]["agent_id"]: connection["agent_1"],
@@ -45,8 +130,8 @@ def configure_connection(api, config, connection, silent=False):
         "connectionId": connection["agent_connection_id"],
         "changes": changes,
     }
-    utils.BatchedRequest(
-        api.update_connection_services,
+    utils.BatchedRequestBody(
+        api.platform_connection_service_update,
         max_payload_size=utils.MAX_PAYLOAD_SIZE,
         translator=utils._default_translator("changes"),
     )(body=body)
@@ -57,9 +142,9 @@ def configure_connections(api, services_config, connections, silent=False):
     ids = [connection["agent_connection_id"] for connection in connections]
     if not ids:
         return 0, 0
-    connections_services = utils.BatchedRequest(
-        api.get_connection_services,
-        max_payload_size=utils.MAX_QUERY_FIELD_SIZE,
+    connections_services = utils.BatchedRequestQuery(
+        api.platform_connection_service_show,
+        max_query_size=utils.MAX_QUERY_FIELD_SIZE,
     )(ids)["data"]
 
     # Build a map of connections so that it would be quicker to resolve them to subnets
@@ -176,6 +261,14 @@ def configure_network_create(api, config, dry_run, silent=False):
     topology = config[ConfigFields.TOPOLOGY].upper()
     connections = config.get(ConfigFields.CONNECTIONS, {})
 
+    if config.get(ConfigFields.ID) is not None:
+        error = f"Network ID during creation is not allowed."
+        if not silent:
+            click.secho(error, err=True, fg="red")
+            return False
+        else:
+            raise ConfigureNetworkError(error)
+
     if topology not in utils.ALLOWED_NETWORK_TOPOLOGIES:
         error = f"Network topology {topology} is not allowed."
         if not silent:
@@ -233,7 +326,6 @@ def configure_network_create(api, config, dry_run, silent=False):
 
     body = {
         "network_name": config[ConfigFields.NAME],
-        "network_type": sdk.NetworkType.POINT_TO_POINT,
         "network_disable_sdn_connections": not use_sdn,
         "network_metadata": {
             "network_created_by": sdk.NetworkGenesisType.CONFIG,
@@ -246,31 +338,22 @@ def configure_network_create(api, config, dry_run, silent=False):
             f"Would create network {config[ConfigFields.NAME]} as {topology}"
         )
     else:
-        result = utils.WithRetry(api.create_network)(body=body)
+        result = utils.WithRetry(api.platform_network_create)(body=body)
         network_id = result["data"]["network_id"]
         not silent and click.echo(
             f"Created network {config[ConfigFields.NAME]} with id {network_id}"
         )
 
-    body = {
-        "network_id": network_id,
-        "agent_ids": peers,
-        "network_update_by": sdk.NetworkGenesisType.CONFIG,
-    }
     if dry_run:
         not silent and click.echo(
             f"Would create {len(peers)} connections for network {config[ConfigFields.NAME]}"
         )
         return False
     else:
-        connections = utils.BatchedRequest(
-            api.create_connections,
-            translator=utils._default_translator("agent_ids"),
-            max_payload_size=utils.MAX_PAYLOAD_SIZE,
-        )(body=body)["data"]
-        not silent and click.echo(
-            f"Created {len(connections)} connections for network {config[ConfigFields.NAME]}"
+        connections = create_connections(
+            api, network_id, config[ConfigFields.NAME], peers, silent
         )
+
         updated_connections, updated_subnets = configure_connections(
             api, services, connections, silent=silent
         )
@@ -280,7 +363,7 @@ def configure_network_create(api, config, dry_run, silent=False):
         return True
 
 
-def configure_network_delete(api, network, dry_run, silent=False):
+def configure_network_delete(api, network, config, dry_run, silent=False):
     """Deletes existing network's connections and the network itself.
 
     Args:
@@ -292,29 +375,33 @@ def configure_network_delete(api, network, dry_run, silent=False):
     Returns:
         (bool): True if any changes were made and False otherwise
     """
-    connections = utils.WithRetry(api.index_connections)(
-        filter=f"networks[]:{network['id']}", take=utils.TAKE_MAX_ITEMS_PER_CALL
-    )
-    for connection in connections["data"]:
-        if connection["network"]["network_id"] != network["id"]:
-            continue
-        if dry_run:
-            not silent and click.echo(
-                f"Would delete connection {connection['agent_connection_id']}..."
-            )
-        else:
-            utils.WithRetry(api.delete_connection)(connection["agent_connection_id"])
-            not silent and click.echo(
-                f"Deleted connection {connection['agent_connection_id']}."
-            )
+    config_connections = config.get(ConfigFields.CONNECTIONS, {})
+    topology = get_topology(network, config, silent)
+
+    if topology == sdk.MetadataNetworkType.P2P:
+        _, absent, _ = resolve.resolve_p2p_connections(
+            api, config_connections, silent=silent
+        )
+    elif topology == sdk.MetadataNetworkType.P2M:
+        _, absent, _ = resolve.resolve_p2m_connections(
+            api, config_connections, silent=silent
+        )
+    else:
+        _, absent, _ = resolve.resolve_mesh_connections(
+            api, config_connections, silent=silent
+        )
 
     if dry_run:
+        not silent and click.echo(
+            f"Would delete {len(absent)} connections from network {network['name']} ({network['id']})..."
+        )
         not silent and click.echo(
             f"Would delete network {network['name']} ({network['id']})..."
         )
         return False
     else:
-        utils.WithRetry(api.delete_networks)(network["id"])
+        delete_connections(api, absent)
+        utils.WithRetry(api.platform_network_destroy)(network["id"])
         not silent and click.echo(f"Deleted network {network['name']}")
         return True
 
@@ -334,49 +421,12 @@ def configure_network_update(api, network, config, dry_run, silent=False):
     Returns:
         (bool): True if any changes were made and False otherwise
     """
-    topology = config[ConfigFields.TOPOLOGY].upper()
-    if topology != network[ConfigFields.TOPOLOGY] and not config.get(
-        ConfigFields.IGNORE_NETWORK_TOPOLOGY, False
-    ):
-        error = f"Configured and requested network topologies do not match: {network[ConfigFields.TOPOLOGY]} v.s. {topology}."
-        if not silent:
-            click.secho(
-                error,
-                err=True,
-                fg="red",
-            )
-            return False
-        else:
-            raise ConfigureNetworkError(error)
-    elif topology != network[ConfigFields.TOPOLOGY] and config.get(
-        ConfigFields.IGNORE_NETWORK_TOPOLOGY, False
-    ):
-        click.secho(
-            (
-                f"Configured and requested network topologies do not match: "
-                f"{network[ConfigFields.TOPOLOGY]} v.s. {topology}. However, "
-                f"{ConfigFields.IGNORE_NETWORK_TOPOLOGY} is set."
-            ),
-            err=True,
-            fg="yellow",
-        )
-        if network[ConfigFields.TOPOLOGY] != sdk.MetadataNetworkType.P2P:
-            click.secho(
-                "NOTE: It is more practical to override P2P topologies.",
-                err=True,
-                fg="yellow",
-            )
+    topology = get_topology(network, config, silent)
 
-    connections = utils.WithRetry(api.index_connections)(
+    connections = utils.WithRetry(api.platform_connection_index)(
         filter=f"networks[]:{network[ConfigFields.ID]}",
         take=utils.TAKE_MAX_ITEMS_PER_CALL,
     )["data"]
-    # NOTE: This is required due to the way tests are designed. Tests should be refactored.
-    connections = [
-        connection
-        for connection in connections
-        if connection["network"]["network_id"] == network[ConfigFields.ID]
-    ]
     all_agents = resolve.get_all_agents(api, silent)
     resolved_connections = transform.transform_connections(
         all_agents,
@@ -423,37 +473,26 @@ def configure_network_update(api, network, config, dry_run, silent=False):
     current = [frozenset(i) for i in current]
 
     to_add = [list(link) for link in present if link not in current]
-    to_remove = [
-        conn["agent_connection_id"]
-        for link, conn in current_connections.items()
-        if link in absent
-    ]
 
-    for item in to_remove:
-        if dry_run:
-            not silent and click.echo(f"Would remove connection {item}.")
-        else:
-            utils.WithRetry(api.delete_connection)(item)
-            not silent and click.echo(f"Removed connection {item}.")
+    if dry_run:
+        not silent and click.echo(f"Would remove {len(absent)} connections.")
+    else:
+        delete_connections(api, absent)
+        not silent and click.echo(f"Removed {len(absent)} connections.")
 
     added_connections = []
     if dry_run:
         not silent and click.echo(f"Would create {len(to_add)} connections.")
     elif to_add:
-        body = {
-            "network_id": network["id"],
-            "agent_ids": to_add,
-            "network_update_by": sdk.NetworkGenesisType.CONFIG,
-        }
-        added_connections = utils.BatchedRequest(
-            api.create_connections,
-            translator=utils._default_translator("agent_ids"),
-            max_payload_size=utils.MAX_PAYLOAD_SIZE,
-        )(body=body, update_type=sdk.UpdateType.APPEND_NEW)["data"]
-        not silent and click.echo(
-            f"Created {len(to_add)} connections for network {config[ConfigFields.NAME]}"
+        added_connections = create_connections(
+            api, network["id"], config[ConfigFields.NAME], to_add, silent
         )
 
+    to_remove = [
+        conn["agent_connection_id"]
+        for link, conn in current_connections.items()
+        if link in absent
+    ]
     connections = [
         connection
         for connection in connections + added_connections
@@ -493,8 +532,8 @@ def configure_network(api, config, dry_run, silent=False):
             raise ConfigureNetworkError(error)
         return False
 
-    name = config[ConfigFields.NAME]
     id = config.get(ConfigFields.ID)
+    name = config[ConfigFields.NAME]
     state = config[ConfigFields.STATE]
     if state not in (PeerState.PRESENT, PeerState.ABSENT):
         error = f"Invalid network {name} {id if id else ''} state {state}"
@@ -504,11 +543,41 @@ def configure_network(api, config, dry_run, silent=False):
         else:
             raise ConfigureNetworkError(error)
 
+    if (not isinstance(name, str) or not name) or not isinstance(name, (int, str)):
+        error = f"Invalid network name."
+        if not silent:
+            click.secho(error, fg="red", err=True)
+            return False
+        else:
+            raise ConfigureNetworkError(error)
+
+    if (
+        id is not None
+        and ConfigFields.ID in config
+        and (not isinstance(id, int) or id <= 0)
+    ):
+        error = f"Invalid network id."
+        if not silent:
+            click.secho(error, fg="red", err=True)
+            return False
+        else:
+            raise ConfigureNetworkError(error)
+
+    if not resolve.validate_connections(
+        config.get(ConfigFields.CONNECTIONS, {}), silent
+    ):
+        error = f"Invalid {ConfigFields.CONNECTIONS} format."
+        if not silent:
+            click.secho(error, fg="red", err=True)
+            return False
+        else:
+            raise ConfigureNetworkError(error)
+
     not silent and click.secho(
         f"Configuring network {name} {id if id else ''}", fg="green"
     )
 
-    networks = utils.WithRetry(api.index_networks)(
+    networks = utils.WithRetry(api.platform_network_index)(
         filter=f"id|name:'{name if id is None else id}'",
         take=utils.TAKE_MAX_ITEMS_PER_CALL,
     )["data"]
@@ -525,7 +594,9 @@ def configure_network(api, config, dry_run, silent=False):
             api, networks[0], config, dry_run, silent=silent
         )
     elif len(networks) == 1 and state == PeerState.ABSENT:
-        return configure_network_delete(api, networks[0], dry_run, silent=silent)
+        return configure_network_delete(
+            api, networks[0], config, dry_run, silent=silent
+        )
     elif len(networks) > 1:
         not silent and click.secho(
             f"There are more than one network by the name {name}",
